OSI Batteries - Leaders in Replacement Batteries
Description: OSI Batteries offers a complete line of replacement batteries for electronics, communications, consumer, manufacturing and industrial applications.
Keywords: Replacement batteries, OEM Batteries, Communication Batteries, Medical Batteries, Industrial Batteries, Enersys, Saft, Duracell

- 800-626-4173
- Contact
- Account
- (0)

## Business to Business Battery Solutions

###

A full line replacement battery company for over 40 years, OSI Batteries is truly your ONE SOURCE for all your replacement battery needs. We have thousands of replacement batteries for almost any kind of equipment. We support all types of businesses and government agencies in communications, industrial, and medical industries.

Read More...

#### Featured Brands

#### Quote Requests

OSI Batteries is a factory direct authorized distributor and value add center for the industries top manufacturers including Enersys. We also import our own line of communication and bar code scanner batteries and accessories. Our in house assembly team is capable of production runs large and small. If you are looking for a large quantity of batteries or if you would like us to beat a competitor's price Request A Quote Today

#### Wholesale Accounts

OSI Batteries has over 40 years of experience servicing businesses and institutions large and small. Our broad product range helps all of our business customers fulfill their battery needs. We have several purchasing programs available to make purchasing batteries for your entire organization easy. Learn More About Wholesale Accounts...

Featured Products

Bullard T3 T3MAX T4 T4MAX T.I.C. Charger Conditioner T3NIMH
Harris P5300 Battery 2500mAh Lithium Ion
EnerSys Genesis Pure Lead XE95 0790-6001 Battery 12V 95Ah

### What's New

Now Stocking FAA-PMA approved SBS-J16 Batteries

All Recently Added Products...